PyXMake Developer Guide: PyXMake.VTL.abaqus Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.abaqus Namespace Reference

## Functions
| main (BuildID, files="mcd_astandard", command=VTL.GetBuildCommand(6), libs=['mcd_corex64']+VTL.GetLinkDependency(0), source=os.path.join(__mcd_core_path,"solver"), include=list(Utility.ArbitraryFlattening([[os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch)], [os.path.join(__mcd_core_path,"include", Utility.GetPlatform(), __arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)]])), dependency=os.path.join(__mcd_core_path,"lib", Utility.GetPlatform(), __arch), output=os.path.join(__mcd_core_path,"bin", Utility.GetPlatform(), __arch), scratch=VTL.Scratch, verbosity=2, **kwargs)

## Variables
| parser = argparse.ArgumentParser(description='CLI wrapper options for ABAQUS make command.', parents=[Custom.__parser__()])
| nargs
| default
| help
| _ = sys.argv[1]
| args
| project = args.name[0]
| source = args.source[0]
| files
| libs = args.libs
| output
| scratch
dict | settings = {"source":source, "output":output, "files":files, "scratch": scratch, "libs": libs}
| path = list(Utility.ArbitraryFlattening(getattr(args,option)));
| sanitized = Utility.GetSanitizedDataFromCommand(path)
str | BuildID = 'mcd_abaqus'

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile MCODAC for ABAQUS Standard & Explicit
                 on Windows. Can be combined with self-written code alike.
    Created on 25.06.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.abaqus.main | ( |  | BuildID,
|  |  | files = "mcd_astandard",
|  |  | command = VTL.GetBuildCommand(6),
|  |  | libs = ['mcd_corex64'] + VTL.GetLinkDependency(0),
|  |  | source = os.path.join(__mcd_core_path,"solver"),
|  |  | include = list(Utility.ArbitraryFlattening([[os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch)], [os.path.join(__mcd_core_path,"include",Utility.GetPlatform(),__arch, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, __arch)]])),
|  |  | dependency = os.path.join(__mcd_core_path,"lib",Utility.GetPlatform(),__arch),
|  |  | output = os.path.join(__mcd_core_path,"bin",Utility.GetPlatform(),__arch),
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 2,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 57 of file abaqus.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.abaqus._ = sys.argv[1]
| protected

Definition at line 104 of file abaqus.py.

## ◆ args

PyXMake.VTL.abaqus.args

Definition at line 105 of file abaqus.py.

## ◆ BuildID

str PyXMake.VTL.abaqus.BuildID = 'mcd_abaqus'

Definition at line 146 of file abaqus.py.

## ◆ default

PyXMake.VTL.abaqus.default

Definition at line 99 of file abaqus.py.

## ◆ files

PyXMake.VTL.abaqus.files

Definition at line 111 of file abaqus.py.

## ◆ help

PyXMake.VTL.abaqus.help

Definition at line 99 of file abaqus.py.

## ◆ libs

list PyXMake.VTL.abaqus.libs = args.libs

Definition at line 115 of file abaqus.py.

## ◆ nargs

PyXMake.VTL.abaqus.nargs

Definition at line 99 of file abaqus.py.

## ◆ output

PyXMake.VTL.abaqus.output

Definition at line 120 of file abaqus.py.

## ◆ parser

PyXMake.VTL.abaqus.parser = argparse.ArgumentParser(description='CLI wrapper options for ABAQUS make command.', parents=[Custom.__parser__()])

Definition at line 98 of file abaqus.py.

## ◆ path

list PyXMake.VTL.abaqus.path = list(Utility.ArbitraryFlattening(getattr(args,option)));

Definition at line 133 of file abaqus.py.

## ◆ project

PyXMake.VTL.abaqus.project = args.name[0]

Definition at line 107 of file abaqus.py.

## ◆ sanitized

PyXMake.VTL.abaqus.sanitized = Utility.GetSanitizedDataFromCommand(path)

Definition at line 135 of file abaqus.py.

## ◆ scratch

PyXMake.VTL.abaqus.scratch

Definition at line 123 of file abaqus.py.

## ◆ settings

dict PyXMake.VTL.abaqus.settings = {"source":source, "output":output, "files":files, "scratch": scratch, "libs": libs}

Definition at line 126 of file abaqus.py.

## ◆ source

PyXMake.VTL.abaqus.source = args.source[0]

Definition at line 109 of file abaqus.py.